Right now, kernel config check is taking in excess of 4000 seconds before spending merely 200s to compile. The kernel config is as such: SRC_URI += "file://defconfig \ file://bsp/${BSP_SUBTYPE}/intel-dev.scc \ " SRC_URI += "${@bb.utils.contains('DISTRO_FEATURES', 'hardened', 'file://bsp/${BSP_SUBTYPE}/security.scc', '', d)}" defconfig is a basic kernel config file with defaults intel-dev contains intel specific hardware, which includes about 8 cfg files. security.scc pulls in a single cfg file for kernel security features.
defconfgs are a pathological case, since they contain thousands of options which all need to be checked. That being said, there are improvements that can be done here, and I've identified a way to shortcut the process.
While working on another bug in master, I was retrying the optimizations that have already been done and I'm seeing about 14seconds to process a defconfig: --------------- yow-bashfiel-d4 [/home/bruc...trib/build]> time MACHINE=qemunios2 bitbake -f -c kernel_configcheck virtual/kernel NOTE: Executing SetScene Tasks NOTE: Executing RunQueue Tasks NOTE: Tasks Summary: Attempted 296 tasks of which 295 didn't need to be rerun and all succeeded. Summary: There were 2 WARNING messages shown. real 0m14.499s user 0m6.080s sys 0m1.828s ------------- The size of the defconfig is this: cat defconfig | wc -l 1575 And the config.queue looks like this: yow-bashfiel-d4 [/home/bruc...ernel-meta]> pwd /home/bruce/poky-contrib/build/tmp/work-shared/qemunios2/kernel-source/.kernel-meta yow-bashfiel-d4 [/home/bruc...ernel-meta]> cat config.queue configs//./defconfig # non-hardware configs//features/nfsd/nfsd.cfg # non-hardware configs//features/debug/printk.cfg # non-hardware configs//features/netfilter/netfilter.cfg # non-hardware configs//cfg/virtio.cfg # non-hardware ------------------------ So the optimizations/streamlining do seem to be holding. Can you see if this is still happening and send a layer / machine configuration for me to use ?
Hi Bruce, How/where do I get the new code to test out the changes?
I just pushed all of my staged commits to poky-config zedd/wip It is poky master + a few of my changes. I didn't do much in particular to fix this specific issue, which is why I'm interested to see if you are still seeing the slow processing, and getting that config. With defconfigs the processing is supposed to short-circuit and save a lot of time, so it shouldn't be hard to fix if it is still happening.
urk. that last comment should be "poky-contrib".
It appears this is no longer a NEEDINFO bug. If it is, please restate the question.
Nope. Definitely still a needinfo. I asked a question if the performance issue was still present. Until I see a yes/no, answer, and steps to reproduce it is needsinfo.
I don't see the problem happening anymore, so you can go ahead and close this.
(In reply to comment #9) > It appears this is no longer a NEEDINFO bug. If it is, please restate the > question. Again. This is a yes/no answer required to "does this still happen".
Bruce, he answered no, he is no longer seeing it. I would close the bug works for me unless you have something else you want from him than that.
ok. I can do that. We can re-open this if it happens again.